PsramConfig

Struct PsramConfig 

pub struct PsramConfig {
    pub size: PsramSize,
    pub timing: PsramTimingParams,
}
Available on crate feature unstable only.
PSRAM configuration.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Fields

size: PsramSize

Size of PSRAM to map. Default: AutoDetect via MR2 density.

timing: PsramTimingParams

PSRAM timing parameters. Default: 250 MHz.