PsramTimingParams

Struct PsramTimingParams 

pub struct PsramTimingParams {
    pub clock_source: PsramFunctionClockConfig,
    pub clock: u32,
    pub mr0_rl: u8,
    pub mr4_wl: u8,
    pub rd_dummy_bits: u8,
    pub wr_dummy_bits: u8,
    pub reg_dummy_bits: u32,
}
Available on crate feature unstable only.
PSRAM timing parameters.

These values should be tuned together with the source clock frequency. The source clock frequency must be an integer multiple of the PSRAM frequency.

Fields

clock_source: PsramFunctionClockConfig

PSRAM clock source.

clock: u32

Bus clock frequency in MHz. Must divide the source clock evenly.

mr0_rl: u8

MR0.read_latency field value (cycles = 2 * value + 6).

mr4_wl: u8

MR4.wr_latency field value.

rd_dummy_bits: u8

Read dummy length in bits for sync data reads (cache path).

For N dummy bits, configure reg_dummy_bits to N - 1.

wr_dummy_bits: u8

Write dummy length in bits for sync data writes (cache path).

For N dummy bits, configure reg_dummy_bits to N - 1.

reg_dummy_bits: u32

Register-read dummy length for direct command path (MSPI3).

Implementations

Source

impl PsramTimingParams

pub const MHZ_20: Self

Preset for 20 MHz clock speed.

pub const MHZ_80: Self

Preset for 80 MHz clock speed.

pub const MHZ_125: Self

Preset for 125 MHz clock speed.

pub const MHZ_200: Self

Preset for 200 MHz clock speed.

pub const MHZ_250: Self

Preset for 250 MHz clock speed.