pub struct PsramTimingParams {
pub clock_source: PsramFunctionClockConfig,
pub clock: u32,
pub mr0_rl: u8,
pub mr4_wl: u8,
pub rd_dummy_bits: u8,
pub wr_dummy_bits: u8,
pub reg_dummy_bits: u32,
}Available on crate feature
unstable only.Expand description
PSRAM timing parameters.
These values should be tuned together with the source clock frequency. The source clock frequency must be an integer multiple of the PSRAM frequency.
Fields
clock_source: PsramFunctionClockConfigPSRAM clock source.
clock: u32Bus clock frequency in MHz. Must divide the source clock evenly.
mr0_rl: u8MR0.read_latency field value (cycles = 2 * value + 6).
mr4_wl: u8MR4.wr_latency field value.
rd_dummy_bits: u8Read dummy length in bits for sync data reads (cache path).
For N dummy bits, configure reg_dummy_bits to N - 1.
wr_dummy_bits: u8Write dummy length in bits for sync data writes (cache path).
For N dummy bits, configure reg_dummy_bits to N - 1.
reg_dummy_bits: u32Register-read dummy length for direct command path (MSPI3).
Implementations